@@ -14,12 +14,12 @@ from graphene_django_cud.mutations.update import (
 )
 from graphql import GraphQLError
 
-from django_scoped_permissions.graphql_util import (
+from django_scoped_permissions.util import (
     expand_scopes_from_context,
     create_resolver_from_method,
     create_resolver_from_scopes,
 )
-from django_scoped_permissions.models import HasScopedPermissionsMixin, ScopedModelMixin
+from django_scoped_permissions.models import ScopedPermissionHolder, ScopedModelMixin
 
 
 class ScopedDjangoNodeOptions(DjangoObjectTypeOptions):
@@ -115,16 +115,16 @@ class ScopedDjangoCreateMutation(DjangoCreateMutation):
 
     @classmethod
     def check_permissions(cls, root, info, input) -> None:
-        permissions = cls.get_permissions(root, info, input)
+        permissions = cls.get_permissions(root, info, input) or []
 
-        if len(permissions) == 0:
+        if not hasattr(permissions, '__len__') or len(permissions) == 0:
             return
 
         context = {"context": info.context, "input": input}
 
         expanded_permissions = expand_scopes_from_context(permissions, context)
 
-        if not isinstance(info.context.user, HasScopedPermissionsMixin):
+        if not isinstance(info.context.user, ScopedPermissionHolder):
             raise GraphQLError("You are not permitted to view this.")
 
         if not info.context.user.has_scoped_permissions(*expanded_permissions):
@@ -136,16 +136,16 @@ class ScopedDjangoBatchCreateMutation(DjangoBatchCreateMutation):
 
     @classmethod
     def check_permissions(cls, root, info, input) -> None:
-        permissions = cls.get_permissions(root, info, input)
+        permissions = cls.get_permissions(root, info, input) or []
 
-        if len(permissions) == 0:
+        if not hasattr(permissions, '__len__') or len(permissions) == 0:
             return
 
         context = {"context": info.context, "input": input}
 
         expanded_permissions = expand_scopes_from_context(permissions, context)
 
-        if not isinstance(info.context.user, HasScopedPermissionsMixin):
+        if not isinstance(info.context.user, ScopedPermissionHolder):
             raise GraphQLError("You are not permitted to view this.")
 
         if not info.context.user.has_scoped_permissions(*expanded_permissions):
@@ -162,9 +162,9 @@ class ScopedDjangoPatchMutation(DjangoPatchMutation):
 
     @classmethod
     def get_permissions(cls, root, info, input, id, obj) -> Iterable[str]:
-        super_permissions = super().get_permissions(root, info, input, id, obj)
+        super_permissions = super().get_permissions(root, info, input, id, obj) or []
 
-        if super_permissions is not None and len(super_permissions) > 0:
+        if hasattr(super_permissions, '__len__') and len(super_permissions) > 0:
             return super_permissions
 
         # If we don't have explicit permissions we use some defaults here.
@@ -192,7 +192,7 @@ class ScopedDjangoPatchMutation(DjangoPatchMutation):
 
         expanded_permissions = expand_scopes_from_context(permissions, context)
 
-        if not isinstance(info.context.user, HasScopedPermissionsMixin):
+        if not isinstance(info.context.user, ScopedPermissionHolder):
             raise GraphQLError("You are not permitted to view this.")
 
         if not info.context.user.has_scoped_permissions(*expanded_permissions):
@@ -220,9 +220,9 @@ class ScopedDjangoUpdateMutation(DjangoUpdateMutation):
 
     @classmethod
     def get_permissions(cls, root, info, input, id, obj) -> Iterable[str]:
-        super_permissions = super().get_permissions(root, info, input, id, obj)
+        super_permissions = super().get_permissions(root, info, input, id, obj) or []
 
-        if len(super_permissions) > 0:
+        if hasattr(super_permissions, '__len__') and len(super_permissions) > 0:
             return super_permissions
 
         # If we don't have explicit permissions we use some defaults here.
@@ -236,7 +236,7 @@ class ScopedDjangoUpdateMutation(DjangoUpdateMutation):
 
     @classmethod
     def check_permissions(cls, root, info, input, id, obj) -> None:
-        permissions = cls.get_permissions(root, info, input, id, obj)
+        permissions = cls.get_permissions(root, info, input, id, obj) or []
 
         context = {}
 
@@ -250,7 +250,7 @@ class ScopedDjangoUpdateMutation(DjangoUpdateMutation):
 
         expanded_permissions = expand_scopes_from_context(permissions, context)
 
-        if not isinstance(info.context.user, HasScopedPermissionsMixin):
+        if not isinstance(info.context.user, ScopedPermissionHolder):
             raise GraphQLError("You are not permitted to view this.")
 
         if not info.context.user.has_scoped_permissions(*expanded_permissions):
@@ -278,9 +278,9 @@ class ScopedDjangoDeleteMutation(DjangoDeleteMutation):
 
     @classmethod
     def get_permissions(cls, root, info, id, obj) -> Iterable[str]:
-        super_permissions = super().get_permissions(root, info, id, obj)
+        super_permissions = list(super().get_permissions(root, info, id, obj))
 
-        if len(super_permissions) > 0:
+        if hasattr(super_permissions, '__len__') and len(super_permissions) > 0:
             return super_permissions
 
         # If we don't have explicit permissions we use some defaults here.
@@ -294,7 +294,7 @@ class ScopedDjangoDeleteMutation(DjangoDeleteMutation):
 
     @classmethod
     def check_permissions(cls, root, info, id, obj) -> None:
-        permissions = cls.get_permissions(root, info,  id, obj)
+        permissions = cls.get_permissions(root, info,  id, obj) or []
 
         context = {}
 
@@ -308,7 +308,7 @@ class ScopedDjangoDeleteMutation(DjangoDeleteMutation):
 
         expanded_permissions = expand_scopes_from_context(permissions, context)
 
-        if not isinstance(info.context.user, HasScopedPermissionsMixin):
+        if not isinstance(info.context.user, ScopedPermissionHolder):
             raise GraphQLError("You are not permitted to view this.")
 
         if not info.context.user.has_scoped_permissions(*expanded_permissions):
@@ -332,16 +332,16 @@ class ScopedDjangoBatchDeleteMutation(DjangoBatchDeleteMutation):
 
     @classmethod
     def check_permissions(cls, root, info, input) -> None:
-        permissions = cls.get_permissions(root, info, input)
+        permissions = list(cls.get_permissions(root, info, input)) or []
 
-        if len(permissions) == 0:
+        if not hasattr(permissions, '__len__') or len(permissions) == 0:
             return
 
         context = {"context": info.context, "input": input}
 
         expanded_permissions = expand_scopes_from_context(permissions, context)
 
-        if not isinstance(info.context.user, HasScopedPermissionsMixin):
+        if not isinstance(info.context.user, ScopedPermissionHolder):
             raise GraphQLError("You are not permitted to view this.")
 
         if not info.context.user.has_scoped_permissions(*expanded_permissions):
@@ -354,16 +354,16 @@ class ScopedDjangoFilterDeleteMutation(DjangoFilterDeleteMutation):
 
     @classmethod
     def check_permissions(cls, root, info, input) -> None:
-        permissions = cls.get_permissions(root, info, input)
+        permissions = list(cls.get_permissions(root, info, input)) or []
 
-        if len(permissions) == 0:
+        if not hasattr(permissions, '__len__') or len(permissions) == 0:
             return
 
         context = {"context": info.context, "input": input}
 
         expanded_permissions = expand_scopes_from_context(permissions, context)
 
-        if not isinstance(info.context.user, HasScopedPermissionsMixin):
+        if not isinstance(info.context.user, ScopedPermissionHolder):
             raise GraphQLError("You are not permitted to view this.")
 
         if not info.context.user.has_scoped_permissions(*expanded_permissions):
